'use strict';

var fetchres = require('fetchres');
var catchNetworkErrors = require('./utils/catch-network-errors');
var logger = require('ft-next-logger');

module.exports = function(opts) {
	var uuid = opts.uuid;
	var useElasticSearch = opts.useElasticSearch;

	if (useElasticSearch && !process.env.ELASTIC_SEARCH_URL) {
		useElasticSearch = false;
		logger.warn('Cannot use elastic search without an ELASTIC_SEARCH_URL');
	}

	var url = useElasticSearch
		? process.env.ELASTIC_SEARCH_URL + '/' + uuid
		: 'http://api.ft.com/content/items/v1/' + uuid + '?feature.blogposts=on';

	return fetch(url, {
			timeout: 3000,
			headers: {
				'X-Api-Key': process.env.apikey
			}
		})
			.catch(catchNetworkErrors)
			.then(function(response) {
				if (!response.ok) {
					logger.warn('Failed getting CAPIv1 content', {
						uuid: uuid,
						status: response.status
					});
				}
				return response;
			})
			.then(fetchres.json)
			.then(function(data) {
				return useElasticSearch ? data._source : data;
			});
};
