'use strict';

var fetchres = require('fetchres');
var content = require('./content');
var catchNetworkErrors = require('./utils/catch-network-errors');
var logger = require('ft-next-logger');

module.exports = function(opts) {
	var query = opts.query;
	var count = opts.count;
	var url = 'http://api.ft.com/content/search/v1';

	var body = {
		queryString: query,
		queryContext: {
			curations: ["ARTICLES", "BLOGS"]
		}
	};

	if (count) {
		body.resultContext = {
			maxResults: count,
			offset: 0
		};
	}

	return fetch(url, {
			timeout: 3000,
			body: JSON.stringify(body),
			method: 'post',
			headers: {
				'Content-Type': 'application/json',
				'X-Api-Key': process.env.apikey
			}
		})
			.catch(catchNetworkErrors)
			.then(function(response) {
				if (!response.ok) {
					logger.warn('Failed getting SAPIv1 content', {
						query: query,
						status: response.status
					});

				}
				return response;
			})
			.then(fetchres.json)
			.then(function(result) {
				if (result.results[0].indexCount === 0) {
					return [];
				}
				result = Promise.all(result.results[0].results.map(function(article) {
					return content({
							uuid: article.id,
							type: 'Article'
						})
							.catch(function(err) {
								if (err instanceof fetchres.BadServerResponseError) {
									return undefined;
								} else {
									throw err;
								}
							});
					}))
					.then(function(articles) {
						return articles.filter(function(article) {
							return article;
						});
					});
				return result;
			});
};
