/*global describe, it*/
'use strict';

require('es6-promise').polyfill();
GLOBAL.fetch = require('node-fetch');
var api = require('../main');

var nock = require('nock');
var expect = require('chai').expect;
nock('http://api.ft.com')
	.get('/content?isAnnotatedBy=http://api.ft.com/things/5c7592a8-1f0c-11e4-b0cb-b2227cce2b54')
	.reply(200, require('./fixtures/capi-v2-is-annotated-by'))
	.get('/content/12dc0348-d780-11e4-94b1-00144feab7de')
	.reply(200, require('./fixtures/capi-v2-article'))
	.get('/content/a0d9ce37-f3f0-3999-8be1-342d3988438c')
	.reply(200, require('./fixtures/capi-v2-article-a0d9ce37'))
	.get('/content/24d3b305-9f9d-3fb8-9ddc-f33a22eeb248')
	.reply(200, require('./fixtures/capi-v2-article-24d3b305'))
	.get('/lists/3c99c2ba-a6ae-11e2-95b1-00144feabdc0')
	.reply(200, require('./fixtures/capi-v2-lists'))
	.get('/organisations/89a11e71-2651-3ded-bd99-cbf02cddcfb4')
	.reply(200, require('./fixtures/capi-v2-organisation'))
	.post('/content/search/v1')
	.reply(200, require('./fixtures/sapi-v1-empty'));

describe('content', function() {
	it('should return content', function() {
		return api.content({
				uuid: '12dc0348-d780-11e4-94b1-00144feab7de'
			})
			.then(function(article) {
				expect(article.title).to.be.a.string;
			});
	});
});

describe('organisation', function() {
	it('should return content', function() {
		return api.organisations({
				uuid: '89a11e71-2651-3ded-bd99-cbf02cddcfb4'
			})
			.then(function(article) {
				expect(article.title).to.be.a.string;
			});
	});
});

describe('lists', function() {
	it('should return content', function() {
		return api.lists({
				uuid: '3c99c2ba-a6ae-11e2-95b1-00144feabdc0'
			})
			.then(function(list) {
				expect(list.title).to.be.a.string;
				expect(list.items.length).to.equal(3);
			});
	});
});

describe('is-annotated-by', function() {
	it('should return content', function() {
		return api.contentAnnotatedBy({
				uuid: '5c7592a8-1f0c-11e4-b0cb-b2227cce2b54'
			})
			.then(function(articles) {
				expect(articles.length).to.equal(2);
				expect(articles[0].title).to.equal('Obama urges peaceful transistion in Nigeria');
				expect(articles[1].title).to.equal('Daiichi Sankyo to merge US businesses');
			});
	});
});

describe('search-legacy', function() {
	it('should behave gracefully when there are no results', function() {
		return api.searchLegacy({
			query: 'no results please'
		})
			.then(function(articles) {
				expect(articles.length).to.equal(0);
			});
	});
});
